@@ -1,47 +1,19 @@
 ( cd opt/kde/share/doc/HTML/sl/kdm ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sl/kdm ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
-( cd opt/kde/share/doc/HTML/sl/kit ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sl/kit ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
-( cd opt/kde/share/doc/HTML/sl/kate ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sl/kate ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
-( cd opt/kde/share/doc/HTML/sl/kdvi ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sl/kdvi ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
 ( cd opt/kde/share/doc/HTML/sl/kppp ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sl/kppp ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
-( cd opt/kde/share/doc/HTML/sl/ksysguard ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sl/ksysguard ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
 ( cd opt/kde/share/doc/HTML/sl/kdesu ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sl/kdesu ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
-( cd opt/kde/share/doc/HTML/sl/kcron ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sl/kcron ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
-( cd opt/kde/share/doc/HTML/sl/kedit ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sl/kedit ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
 ( cd opt/kde/share/doc/HTML/sl/kfind ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sl/kfind ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
-( cd opt/kde/share/doc/HTML/sl/kuser ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sl/kuser ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
-( cd opt/kde/share/doc/HTML/sl/klipper ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sl/klipper ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
-( cd opt/kde/share/doc/HTML/sl/ksnapshot ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sl/ksnapshot ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
-( cd opt/kde/share/doc/HTML/sl/konsole ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sl/konsole ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
 ( cd opt/kde/share/doc/HTML/sl/kpackage ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sl/kpackage ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
-( cd opt/kde/share/doc/HTML/sl/khelpcenter/faq ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sl/khelpcenter/faq ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
 ( cd opt/kde/share/doc/HTML/sl/khelpcenter/quickstart ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sl/khelpcenter/quickstart ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
-( cd opt/kde/share/doc/HTML/sl/khelpcenter/glossary ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sl/khelpcenter/glossary ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
 ( cd opt/kde/share/doc/HTML/sl/khelpcenter ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sl/khelpcenter ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
 ( cd opt/kde/share/doc/HTML/sl/khelpcenter/userguide ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sl/khelpcenter/userguide ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
-( cd opt/kde/share/doc/HTML/sl/khelpcenter/visualdict ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sl/khelpcenter/visualdict ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
-( cd opt/kde/share/doc/HTML/sl/kmenuedit ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sl/kmenuedit ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
 ( cd opt/kde/share/doc/HTML/sl/kioslave ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sl/kioslave ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
 ( cd opt/kde/share/doc/HTML/sl/kaddressbook ; rm -rf common )
@@ -82,6 +54,8 @@
 ( cd opt/kde/share/doc/HTML/sl/common ; ln -sf ../../en/common/grad.png grad.png )
 ( cd opt/kde/share/doc/HTML/sl/common ; rm -rf kde-web.css )
 ( cd opt/kde/share/doc/HTML/sl/common ; ln -sf ../../en/common/kde-web.css kde-web.css )
+( cd opt/kde/share/doc/HTML/sl/common ; rm -rf kde_logo_bg.png )
+( cd opt/kde/share/doc/HTML/sl/common ; ln -sf ../../en/common/kde_logo_bg.png kde_logo_bg.png )
 ( cd opt/kde/share/doc/HTML/sl/common ; rm -rf lgpl-license.html )
 ( cd opt/kde/share/doc/HTML/sl/common ; ln -sf ../../en/common/lgpl-license.html lgpl-license.html )
 ( cd opt/kde/share/doc/HTML/sl/common ; rm -rf doxygen.css )
@@ -96,12 +70,16 @@
 ( cd opt/kde/share/doc/HTML/sl/common ; ln -sf ../../en/common/footer.html footer.html )
 ( cd opt/kde/share/doc/HTML/sl/common ; rm -rf kde-common.css )
 ( cd opt/kde/share/doc/HTML/sl/common ; ln -sf ../../en/common/kde-common.css kde-common.css )
+( cd opt/kde/share/doc/HTML/sl/common ; rm -rf appheader.html )
+( cd opt/kde/share/doc/HTML/sl/common ; ln -sf ../../en/common/appheader.html appheader.html )
 ( cd opt/kde/share/doc/HTML/sl/common ; rm -rf doctop1.png )
 ( cd opt/kde/share/doc/HTML/sl/common ; ln -sf ../../en/common/doctop1.png doctop1.png )
 ( cd opt/kde/share/doc/HTML/sl/common ; rm -rf doctop2.png )
 ( cd opt/kde/share/doc/HTML/sl/common ; ln -sf ../../en/common/doctop2.png doctop2.png )
 ( cd opt/kde/share/doc/HTML/sl/common ; rm -rf shadow.png )
 ( cd opt/kde/share/doc/HTML/sl/common ; ln -sf ../../en/common/shadow.png shadow.png )
+( cd opt/kde/share/doc/HTML/sl/common ; rm -rf kde_logo.png )
+( cd opt/kde/share/doc/HTML/sl/common ; ln -sf ../../en/common/kde_logo.png kde_logo.png )
 ( cd opt/kde/share/doc/HTML/sl/common ; rm -rf docheadergears.png )
 ( cd opt/kde/share/doc/HTML/sl/common ; ln -sf ../../en/common/docheadergears.png docheadergears.png )
 ( cd opt/kde/share/doc/HTML/sl/common ; rm -rf fdl-license.html )
@@ -176,18 +154,6 @@
 ( cd opt/kde/share/doc/HTML/sl/kcontrol/kcmlowbatwarn ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
 ( cd opt/kde/share/doc/HTML/sl/kcontrol/keyboard ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sl/kcontrol/keyboard ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
-( cd opt/kde/share/doc/HTML/sl/kicker ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sl/kicker ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
-( cd opt/kde/share/doc/HTML/sl/kpager ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sl/kpager ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
-( cd opt/kde/share/doc/HTML/sl/kruler ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sl/kruler ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
-( cd opt/kde/share/doc/HTML/sl/kwrite ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sl/kwrite ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
-( cd opt/kde/share/doc/HTML/sl/noatun ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sl/noatun ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
-( cd opt/kde/share/doc/HTML/sl/kdebugdialog ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sl/kdebugdialog ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
 ( cd opt/kde/share/doc/HTML/sl/kinfocenter/dma ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sl/kinfocenter/dma ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
 ( cd opt/kde/share/doc/HTML/sl/kinfocenter/pci ; rm -rf common )
@@ -210,5 +176,3 @@
 ( cd opt/kde/share/doc/HTML/sl/kinfocenter/processor ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
 ( cd opt/kde/share/doc/HTML/sl/kinfocenter/protocols ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sl/kinfocenter/protocols ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
-( cd opt/kde/share/doc/HTML/sl/konqueror ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sl/konqueror ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
